@@ -11,9 +11,7 @@ class Client():
 
     def start(self):
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        self.socket.settimeout(1)
         self.socket.connect((self.IP, self.PORT))
-        self.socket.settimeout(None)
 
     def send(self, data, key=None):
         data = json.dumps(data)
@@ -27,7 +25,15 @@ class Client():
             utils.debug(data,"json Decode Error")
             return ""
         return data
+    
+    def subscribe(self, name=""):
+        if self.socket:
+            if name=="":
+                self.send({"action":"subscribe"})
+            else:
+                self.send({"action":"subscribe", "name":name})
+
+    def getClients(self):
+        if self.socket:
+            self.send({"action":"getClients"})
 
-    def close(self):
-        if socket:
-            self.socket.close()
\ No newline at end of file
